/*
 * @( # )NumberTable.java
 *
 * Copyright ( c ) 2003 masahito suzuki, Inc. All Rights Reserved
 */
package com.JRcServer.commons.util;

import java.io.Serializable;

import com.JRcServer.commons.serialize.SerializeUtil;

/**
 * NumberTableオブジェクト.
 * <BR><BR>
 * Number( int )情報を非同期モードで管理するオブジェクトです.<BR>
 * このオブジェクトは非同期モードです.<BR>
 * このオブジェクトは、同期モード[NumberTableSync]オブジェクトに比べて
 * 約１５％高速で動作しますが、スレッド間アクセスを行った場合、内容は保証
 * されません.<BR>
 * 同期モードのオブジェクトは[NumberTableSync]オブジェクトを利用してください.
 *
 * @version 1.00, 2000/12/09
 * @author  Masahito Suzuki
 * @since  JRcCommons 1.00
 */
public class NumberTable implements Serializable
{
    
    static {
        serialVersionUID = SerializeUtil.serialVersionUID(
            NumberTable.class.getName()
        ) ;
    }
    
    /**
     * シリアライズUID.
     */
    private static final long serialVersionUID ;
    
    /**
     * データ管理オブジェクト.
     */
    private CoreNumberTable m_info = null ;
    
    /**
     * コンストラクタ.
     */
    public NumberTable()
    {
        m_info = new CoreNumberTable() ;
    }
    
    /**
     * コンストラクタ.
     * <BR><BR>
     * 検索コードを指定して生成します.
     * <BR>
     * @param searchNo 検索コードを設定します.<BR>
     *                 設定可能な最小値は[0]です.<BR>
     *                 設定可能な最大値は[7]です.
     */
    public NumberTable( int searchNo )
    {
        m_info = new CoreNumberTable( searchNo ) ;
    }
    
    /**
     * ファイナライズ処理定義.
     * <BR><BR>
     * ファイナライズ処理定義.
     * @exception Exception 例外処理が返されます.
     */
    protected final void finalize() throws Exception
    {
        
        try{
            this.clear() ;
        }catch( Exception t ){
        }
        
    }
    
    /**
     * 情報クリア.
     * <BR><BR>
     * 情報をクリアします.
     */
    public final void clear()
    {
        m_info.clear() ;
    }
    
    /**
     * 情報の追加.
     * <BR><BR>
     * 管理オブジェクトに数値列を追加します.
     * <BR>
     * @param num 追加対象の数値情報を設定します.<BR>
     *             すでに同一情報が存在する場合、上書きします.
     * @param value 追加対象の要素情報を設定します.
     */
    public final void add( int num,Object value )
    {
        m_info.add( num,value ) ;
    }
    
    /**
     * 指定情報の削除.
     * <BR><BR>
     * 指定された情報を削除します.
     * <BR>
     * @param num 削除対象の数値情報を指定します.
     * @return Object 削除された情報の要素が返されます.
     */
    public final Object remove( int num )
    {
        Object ret = null ;
        
        ret = m_info.remove( num ) ;
        
        return ret ;
    }
    
    /**
     * 情報取得.
     * <BR><BR>
     * 指定数値列の情報を取得します.
     * <BR>
     * @param num 取得対象の数値情報を指定します.
     * @return Object 取得された情報の要素が返されます.
     */
    public final Object get( int num )
    {
        return m_info.get( num ) ;
    }
    
    /**
     * 数値に対する存在チェック.
     * <BR><BR>
     * 数値に対する存在チェックを行います.
     * <BR>
     * @param num チェック対象の数値を設定します.
     * @return boolean 存在結果が返されます.<BR>
     *                 [true]が返された場合、情報は存在します.<BR>
     *                 [false]が返された場合、情報は存在しません.
     */
    public final boolean isData( int num )
    {
        return m_info.isData( num ) ;
    }
    
    /**
     * 格納情報数の取得.
     * <BR><BR>
     * 格納情報数が返されます.
     * <BR>
     * @return int 格納情報数が返されます.
     */
    public final int size()
    {
        return m_info.size() ;
    }
    
    /**
     * 格納数値配列の取得.
     * <BR><BR>
     * 格納されているキーとなる数値をすべて取得します.
     * <BR>
     * @return int[] 格納数値配列が返されます.<BR>
     *               情報が存在しない場合[null]が返されます.
     */
    public final int[] getNumbers()
    {
        return m_info.getNumbers() ;
    }
}
